@@ -41,6 +41,7 @@ export class RobotModel {
   points: any = [];
   traceColor: string = 'red';
   speed: number = 1;
+  bs: number;
 
   world: WorldModel;
 
@@ -60,6 +61,7 @@ export class RobotModel {
     this.world = world;
     this.canvas = this.world.ui.layers.main;
     this.speed = 0.1;
+    this.bs = this.world.bs;
   }
 
   cr2xy(x: number, y: number) {
@@ -81,8 +83,8 @@ export class RobotModel {
     let trace = new Konva.Line({
       points: this.points.slice(Math.max(this.points.length - 4, 0)),
       stroke: this.traceColor,
-      x: 25,
-      y: 25,
+      x: this.bs / 2,
+      y: this.bs / 2,
     });
     this.world.ui.layers.line.add(trace);
     this.world.ui.layers.line.draw();
@@ -159,8 +161,8 @@ export class RobotModel {
         node.setAttrs({
           x: cx,
           y: cy,
-          width: 35,
-          height: 35,
+          width: this.bs - 15,
+          height: this.bs - 15,
           rotation: -(this.orientation * 90),
         });
         this.node = node;
@@ -176,8 +178,8 @@ export class RobotModel {
         node.setAttrs({
           x: cx,
           y: cy,
-          width: 35,
-          height: 35,
+          width: this.bs - 15,
+          height: this.bs - 15,
           rotation: -(this.orientation * 90),
         });
         this.node = node;
