@@ -50,6 +50,7 @@ export class WorldModel {
   messages: any;
   pending_goals: any;
   drop_goals: any;
+  flags: any;
   stats: {
     basket?: any;
     current_load?: number;
@@ -83,6 +84,7 @@ export class WorldModel {
     tileMap = {},
     tiles = [],
     messages = {},
+    flags = {},
     pending_goals = [],
     drop_goals = []
   ) {
@@ -102,6 +104,7 @@ export class WorldModel {
     this.pending_goals = pending_goals;
     this.drop_goals = drop_goals;
     this.messages = messages;
+    this.flags = flags;
     this.draw_canvas();
 
     this.robots = robots.map(
@@ -183,6 +186,7 @@ export class WorldModel {
     this.draw_stats();
     this.draw_msg_containers();
     this.draw_envelops();
+    this.draw_flags();
 
     this.draw_drop_goals(this.drop_goals);
 
@@ -361,6 +365,17 @@ export class WorldModel {
     }
   }
 
+  draw_flags() {
+    for (const key in this.flags) {
+      const [x, y] = key.split(',').map((zz) => parseInt(zz));
+      this.draw_flag(x, y);
+    }
+  }
+
+  draw_flag(x: number, y: number) {
+    this.draw_custom('racing_flag', x, y, 0);
+  }
+
   draw_object(x: number, y: number, obj: any) {
     for (const obj_name in obj) {
       let val = this.parse_value(obj[obj_name]);
@@ -435,6 +450,7 @@ export class WorldModel {
       //@ts-ignore
       img.destroy();
     }
+
     this.ui.layers.main.draw();
   }
 
