@@ -103,6 +103,7 @@ export class MazeView extends DOMWidgetView {
     tileMap: any = {},
     tiles: any = [],
     messages: any = {},
+    flags: any = {},
     pending_goals: any = [],
     drop_goals: any = []
   ) => {
@@ -116,6 +117,7 @@ export class MazeView extends DOMWidgetView {
       tileMap,
       tiles,
       messages,
+      flags,
       pending_goals,
       drop_goals
     );
@@ -169,6 +171,10 @@ export class MazeView extends DOMWidgetView {
     return this.world_model.remove_object(x, y);
   };
 
+  remove_flag = (x: number, y: number) => {
+    return this.world_model.remove_object(x, y);
+  };
+
   remove_wall = (x: number, y: number, dir: string) => {
     return this.world_model.remove_wall(x, y, dir);
   };
