@@ -126,7 +126,8 @@ DEFAULT_OBJECTS = [
     "envelope",
     "envelope-30",
     "envelope-sprite",
-    "speech_bubble"
+    "speech_bubble",
+    "robot-yellow"
 ]
 
 
