@@ -48,7 +48,6 @@ class Direction(Enum):
         elif isinstance(direction, int):
             return  Direction(direction)
 
-
 class Cell:
     def __init__(self, x, y, world, background = None, msg = None):
         self.x  = x
@@ -193,6 +192,7 @@ class WorldModel():
         self.options.update(options)
         self.js_call_counter = 1
         self.messages = {}
+        self.flags = {}
 
         if path is not None:
             data = self.load_json(path)
@@ -257,6 +257,16 @@ class WorldModel():
         cell = self.cells[x - 1][y - 1]
         cell.add_msg(msg, call_js)
 
+    def add_flag(self, x,y, call_js=None):
+        pos = "{},{}".format(x,y)
+        self.flags[pos] = 1
+    
+    def remove_flag(self, x, y, call_js=None):
+        pos = "{},{}".format(x,y)
+        del self.flags[pos]
+        self.js_call(call_js, 'remove_flag', [x,y])
+
+        
     def add_description(self, desc):
         if isinstance(desc, list):
             self.description = '\n'.join(desc)
@@ -299,6 +309,9 @@ class WorldModel():
         self._add_goal("reporter", msg)
     
 
+    def add_flag_count_goal(self, count):
+        self._add_goal('flag_count', {'count': count})
+        
     def add_drop_obj_goal(self, x, y, obj_name, val):
         self._add_goal('drop', {"x": x, "y":y , "val": val, "obj_name": obj_name})
     
@@ -363,6 +376,7 @@ class WorldModel():
             self.tilemap,
             self.tiles,
             self.messages,
+            self.flags,
             [x.msg() for x in self.goals],
             [{"obj_name": x.obj_name, "x": x.x, "y": x.y, "val": x.val} for x in self.drop_goals()]
         ])
