@@ -20,6 +20,7 @@ class WorldParser:
         self.parse_messages()
         self.parse_robots()
         self.parse_objects()
+        self.parse_flags()
         self.parse_goals()
         self.parse_description()
     
@@ -55,6 +56,12 @@ class WorldParser:
                 parsed_val = self.parse_val(val)
                 [x,y] = map(int, pos.split(","))
                 self.world.add_object(x, y, obj_name, parsed_val)
+
+    def parse_flags(self):
+        flags = self.config.get('flags', [])
+        for pos in flags:
+            [x, y] = map(int, pos)
+            self.world.add_flag(x, y)
     
 
     def parse_messages(self):
