@@ -32,6 +32,7 @@ class Robot():
         self.max_capacity = None
         self.move_count = 0
         self.stats = Stats(self)
+        self.flag_count = 0
  
     @property
     def x(self):
@@ -89,6 +90,7 @@ class Robot():
             xx, yy = _directions[self.dir]
             self.x += xx
             self.y += yy
+            self._pick_flag()
             self.move_count += 1
         else:
             print_error("Opps You Hit the walls") 
@@ -403,6 +405,18 @@ class Robot():
             return goal.is_completed(self)
         return False
     
+    def on_flag(self):
+        k = "{},{}".format(self.x,self.y)
+        return self.world_model.flags.get(k, 0) == 1
+
+    def carries_flag(self):
+        return self.flag_count > 1
+
+    def _pick_flag(self):
+        if self.on_flag():
+            self.flag_count +=1
+            self.world_model.remove_flag(self.x, self.y, self.world.js_call)    
+
     def put(self):
         cell = self.cell()
         if not cell.editable["drop"]:
